Maintaining Pizza
=================

This document contains guidance on maintaining and contributing to Pizza.
The project README also contains some of this information.

For instructions on installing or using the application, consult the README or
[project page](https://github.com/cjerdonek/groome-python-expected) instead.
For instructions on releasing the application to PyPI and on how to use
`setup.py`, consult the `releasing.md` file in the `docs` folder.

TODO [template]: add instructions for previewing a Markdown file.
